========
graphpkg
========


A package to plot graphs on a dashboard using matplotlib



Description
===========

This package initially started with the idea of plotting live trend graph using matplotlib as base.

visit https://graphpkg.readthedocs.io/ for detailed documentation
